autowisp.processing_steps.create_lightcurves module — AutoWISP documentation

# autowisp.processing_steps.create_lightcurves module

## Class Inheritance Diagram

Create light curves from a collection of DR files.

class autowisp.processing_steps.create_lightcurves.MasterCatalog(configuration)

  Bases: `object`

  Class for managing the master catalog for LC creation.

  __init__(configuration)

    Prepare to add sources to the catalog.

  add_batch(new_sources, new_header)

    Add any sources after a batch of newly created lightcurves.

  is_new()

    True iff the given master is newly created rather than extension.

  save()

    Save the catalog and return the filename.

autowisp.processing_steps.create_lightcurves.cleanup_interrupted(interrupted, configuration)

  Cleanup the file system after interrupted lightcurve creation.

autowisp.processing_steps.create_lightcurves.create_lightcurves(dr_collection, start_status, configuration, mark_start, mark_end)

  Create lightcurves from the data in the given DR files.

autowisp.processing_steps.create_lightcurves.dummy_fname_parser(_)

  No extra keywords to add from filename.

autowisp.processing_steps.create_lightcurves.get_observatory(header, configuration)

  Return (latitude, longitude, altitude) where given data was collected.

autowisp.processing_steps.create_lightcurves.get_path_substitutions(configuration)

  Return the path substitutions for getting data out of DR files.

autowisp.processing_steps.create_lightcurves.has_magfit(dr_fname, substitutions)

  Check if the DR file contains a sky-to-frame transformation.

autowisp.processing_steps.create_lightcurves.main()

  Run the light curve creation step from the command line.

autowisp.processing_steps.create_lightcurves.parse_command_line(*args)

  Return the parsed command line arguments.

autowisp.processing_steps.create_lightcurves.sort_by_observatory(dr_collection, configuration)

  Split the DR files by observatory coords and sort within observatory.